pocketpose.models.wholebody.blazepose - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.models.wholebody.blazepose`

## Module Contents

### Classes

`BlazePose` | Base class for the BlazePose models.
`BlazePoseLite` | BlazePose-Lite model.
`BlazePoseFull` | BlazePose-Full model.
`BlazePoseHeavy` | BlazePose-Heavy model.

class pocketpose.models.wholebody.blazepose.BlazePose(model_path: str, model_url: str, input_size: tuple)

  Bases: `pocketpose.models.interfaces.TFLiteModel`

  Base class for the BlazePose models.

  NUM_KEYPOINTS = 33
  NUM_LANDMARKS = 39
  LANDMARKS_DIM = 5
  HEATMAPS_DIM = 39
  process_image(image)

    Default implementation of process_image() for models that don’t need preprocessing.

    This method can be overridden by subclasses to implement model-specific preprocessing.

    Args:
      image (np.ndarray): The image to prepare for prediction. The image is a numpy

        array with shape (1, height, width, channels) and dtype uint8 (range [0, 255]).

  _calculate_keypoints(landmark_points, heatmap, index, original_size)
  postprocess_prediction(prediction, original_size)

    Postprocess the prediction.

    Args:

      prediction (list): List of outputs from the model. original_size (tuple): Original size of the image as (height, width).

class pocketpose.models.wholebody.blazepose.BlazePoseLite

  Bases: `BlazePose`

  BlazePose-Lite model.

class pocketpose.models.wholebody.blazepose.BlazePoseFull

  Bases: `BlazePose`

  BlazePose-Full model.

class pocketpose.models.wholebody.blazepose.BlazePoseHeavy

  Bases: `BlazePose`

  BlazePose-Heavy model.